@@ -2,7 +2,7 @@
 
 // fixg2sxd - a utility to convert fig to sxd format
 
-// Copyright (C) 2003-2007 Alexander Bürger, acfb@users.sourceforge.net
+// Copyright (C) 2003-2008 Alexander Bürger, acfb@users.sourceforge.net
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -25,12 +25,17 @@
 #include "zipwrite.h"
 
 #include <cstdlib>
+#include <clocale>
 #include <string>
+#include <cstring>
+#include <strings.h>
 #include <iostream>
 #include <fstream>
 #include <sstream>
 #include <vector>
 
+#define SOME_STYLES_ONLY_IN_CONTENT 1
+
 using namespace std;
 
 static int papersize;
@@ -93,19 +98,20 @@ static void write_file( ostream& sxdfile )
     textbaseprop["fo:font-style"] << "normal";
     textbaseprop["fo:color"] << "#000000";
     textbaseprop["fo:font-size"] << "10pt";
+    textbaseprop["fo:padding-left"] << "0cm";
+    textbaseprop["fo:padding-right"] << "0cm";
+    textbaseprop["fo:padding-top"] << "0cm";
+    textbaseprop["fo:padding-bottom"] << "0cm";
     textbaseprop["draw:fill"] << "none";
     textbaseprop["draw:stroke"] << "none";
-    textbaseprop["draw:textarea-vertical-align"] << "center";
-    textbaseprop["draw:textarea-horizontal-align"] << "left";
 
-#if 0
-    // does not work here as of OOo 1.1.0
+#ifndef SOME_STYLES_ONLY_IN_CONTENT
+    // does not work here as of OOo 2.4.0
     Node& narrow = autostyles.subnode("style:style");
-    narrow["style:name"] << "narrow";
+    narrow["style:name"] << "P1";
     narrow["style:family"] << "paragraph";
     Node& narrowprop = narrow.subnode("style:properties");
     narrowprop["style:text-scale"] << "90%";
-    narrowprop["fo:text-align"] << "center";
 #endif
 
     for( set<TextStyle>::iterator i=textstyles.begin();
@@ -210,8 +216,9 @@ static void write_file( ostream& sxdfile )
                    << " office:version=\"1.0\" office:class=\"drawing\">"
                    << endl;
 
+#ifdef SOME_STYLES_ONLY_IN_CONTENT
         // for narrow text, scaling must be defined here; other places
-        // do not work as of OOo 1.1.0
+        // do not work as of OOo 2.4.0
         Node auto2("office:automatic-styles");
         Node& P1 = auto2.subnode("style:style");
         P1["style:name"] << "P1";
@@ -219,6 +226,7 @@ static void write_file( ostream& sxdfile )
         Node& P1prop = P1.subnode("style:properties");
         P1prop["style:text-scale"] << "90%";
         contentxml << auto2;
+#endif
 
         contentxml << "<office:body>" << endl
                    << "<draw:page draw:name=\"page1\""
@@ -410,7 +418,7 @@ static void usage( const char* cmdname, bool err=true )
         << "can be set (in cm), e.g. to 0 to have fine lines." << endl << endl
         << "With -w files with out-of-specification values will be accepted," <<endl
         << "but a warning will be printed and the bad values sanitized." << endl << endl
-        << "This is fig2sxd version 0.17. (C) 2003-2007 Alexander Bürger."
+        << "This is fig2sxd version 0.18. (C) 2003-2008 Alexander Bürger."
         << endl;
 }
 
@@ -452,8 +460,12 @@ extern bool out_of_range_error;
 
 int try_catched_main( int argc, char* argv[] )
 {
+    setlocale( LC_NUMERIC, "C" );
+
     const char* tmp;
-    if( option( "-linewidth1", tmp, argc, argv ) | option( "-lw1", tmp, argc, argv ) ) {
+    if( option( "-linewidth1", tmp, argc, argv )
+        | option( "-lw1", tmp, argc, argv ) )
+    {
         float w = atof( tmp );
         if( w<0 )
             fail( "linewith must be >= 0" );
@@ -477,7 +489,7 @@ int try_catched_main( int argc, char* argv[] )
     }
     if( argc != 3 && !dotfig && !dotxfig ) {
         usage( argv[0], true );
-        exit( -1 );
+        exit( EXIT_FAILURE );
     }
 
     initcolors();
@@ -506,7 +518,7 @@ int try_catched_main( int argc, char* argv[] )
     } else {
         write_file( std::cout );
     }
-    return 0;
+    return EXIT_SUCCESS;
 }
 
 int main( int argc, char* argv[] )
@@ -519,6 +531,6 @@ int main( int argc, char* argv[] )
              << "please contact the author(s) via http://fig2sxd.sourceforge.net/."  << endl
              << "Thank you." << endl << endl
              << "To get your file converted anyway, you could try the '-w' option." << endl;
-        return -1;
+        return EXIT_FAILURE;
     }
 }
